Release Management for libEnsemble
==================================

This section documents the steps to be followed for each libEnsemble release.

.. toctree::
   :maxdepth: 2
   :caption: libEnsemble Release Contents:

   release_process.rst
   release_platforms/index.rst
